==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateEventToCreatorSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToCreator;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToCreatorSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.List;


public class CreateEventToCreatorSetImpl extends InstanceSet<CreateEventToCreatorSet,CreateEventToCreator> implements CreateEventToCreatorSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateEventToCreator createeventtocreator : this ) createeventtocreator.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public CreateSMEventStatementSet R704_is_a_CreateSMEventStatement() throws XtumlException {
        CreateSMEventStatementSet createsmeventstatementset = new CreateSMEventStatementSetImpl();
        for ( CreateEventToCreator createeventtocreator : this ) createsmeventstatementset.add( createeventtocreator.R704_is_a_CreateSMEventStatement() );
        return createsmeventstatementset;
    }


    @Override
    public CreateEventToCreator nullElement() {
        return CreateEventToCreatorImpl.EMPTY_CREATEEVENTTOCREATOR;
    }

    @Override
    public CreateEventToCreatorSet emptySet() {
      return new CreateEventToCreatorSetImpl();
    }

    @Override
    public CreateEventToCreatorSet value() {
        return this;
    }

    @Override
    public List<CreateEventToCreator> elements() {
        return Arrays.asList(toArray(new CreateEventToCreator[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/CreateEventToCreatorSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToCreator;
import io.ciera.tool.sql.ooaofooa.event.CreateEventToCreatorSet;
import io.ciera.tool.sql.ooaofooa.event.CreateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class CreateEventToCreatorSetImpl extends InstanceSet<CreateEventToCreatorSet,CreateEventToCreator> implements CreateEventToCreatorSet {

    public CreateEventToCreatorSetImpl() {
    }

    public CreateEventToCreatorSetImpl(Comparator<? super CreateEventToCreator> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( CreateEventToCreator createeventtocreator : this ) createeventtocreator.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public CreateSMEventStatementSet R704_is_a_CreateSMEventStatement() throws XtumlException {
        CreateSMEventStatementSet createsmeventstatementset = new CreateSMEventStatementSetImpl();
        for ( CreateEventToCreator createeventtocreator : this ) createsmeventstatementset.add( createeventtocreator.R704_is_a_CreateSMEventStatement() );
        return createsmeventstatementset;
    }


    @Override
    public CreateEventToCreator nullElement() {
        return CreateEventToCreatorImpl.EMPTY_CREATEEVENTTOCREATOR;
    }

    @Override
    public CreateEventToCreatorSet emptySet() {
      return new CreateEventToCreatorSetImpl();
    }

    @Override
    public CreateEventToCreatorSet emptySet(Comparator<? super CreateEventToCreator> comp) {
      return new CreateEventToCreatorSetImpl(comp);
    }

    @Override
    public CreateEventToCreatorSet value() {
        return this;
    }

    @Override
    public List<CreateEventToCreator> elements() {
        return Arrays.asList(toArray(new CreateEventToCreator[0]));
    }

}
